@@ -16,7 +16,8 @@ def find_column_labels(
     a collection of expected ``label_fingerprints``.
 
     ``df.columns`` is updated to contain the found column labels and all rows
-    before and including the column label row are removed.
+    before and including the column label row are removed. If the initial
+    column labels of ``df`` fit the match criteria, ``df`` will be unchanged.
 
     .. note::
        All labels must be in the same row. This function will not attempt to
@@ -154,6 +155,23 @@ def find_column_labels(
     if label_match_thresh == 0:
         raise ValueError("label_match_thresh can not be 0.")
 
+    # First, check if the initial labels are already correct. If they are,
+    # exit without changing df.
+
+    label_count = 0
+
+    for cell in df.columns:
+        cell_fingerprint = fingerprint(
+            cell, special_characters=special_characters
+        )
+
+        if cell_fingerprint in label_fingerprints:
+            label_count += 1
+
+    
+    if label_count >= label_match_thresh:
+        return None
+
     # Check whether the index is something other than the default RangeIndex,
     # and temporarily change it to a RangeIndex if it is.
     #
@@ -217,6 +235,8 @@ def merge_columns_by_label(df, deduplicate_values=False):
     will be turned into a column of lists containing the values from all of
     the instances. The other instances will then be dropped.
 
+    ``None`` and ``np.nan`` values will not be included in the merged column.
+
     .. note::
        This function does not fingerprint the labels for comparison. Column
        labels should be cleaned and mapped before using this tool.
@@ -228,7 +248,7 @@ def merge_columns_by_label(df, deduplicate_values=False):
       ...     [
       ...         ["AAA", "aaa@aaa.com", "111-111-1111", "111@aaa.com"],
       ...         ["BAA", "baa@baa.com", "222-222-2222", "222@baa.com"],
-      ...         ["CAA", "caa@caa.com", "333-333-3333", "333@caa.com"],
+      ...         ["CAA", "caa@caa.com", "333-333-3333", None],
       ...         ["DAA", "daa@daa.com", "444-444-4444", "444@daa.com"]
       ...     ],
       ...     columns=["id", "email", "phone", "email"]
@@ -237,14 +257,14 @@ def merge_columns_by_label(df, deduplicate_values=False):
           id        email         phone        email
       0  AAA  aaa@aaa.com  111-111-1111  111@aaa.com
       1  BAA  baa@baa.com  222-222-2222  222@baa.com
-      2  CAA  caa@caa.com  333-333-3333  333@caa.com
+      2  CAA  caa@caa.com  333-333-3333         None
       3  DAA  daa@daa.com  444-444-4444  444@daa.com
       >>> merge_columns_by_label(df)
       >>> print(df)
           id                       email         phone
       0  AAA  [aaa@aaa.com, 111@aaa.com]  111-111-1111
       1  BAA  [baa@baa.com, 222@baa.com]  222-222-2222
-      2  CAA  [caa@caa.com, 333@caa.com]  333-333-3333
+      2  CAA               [caa@caa.com]  333-333-3333
       3  DAA  [daa@daa.com, 444@daa.com]  444-444-4444
 
     :param df:
@@ -266,26 +286,38 @@ def merge_columns_by_label(df, deduplicate_values=False):
 
     for label in duplicate_labels:
         # Get integer location of first instance of label
-        position_array = df.columns.get_loc(label)
-        first_iloc = next(i for i, x in enumerate(position_array) if x)
+        first_iloc = next(i for i, x in enumerate(df.columns) if x == label)
 
-        # Set the values of that column to a list (or set) combining all of the
-        # instances of label
-        if deduplicate_values:
-            deduped_column = []
-            for cell in df[label].values:
-                deduped_column.append(set(cell))
-            df.iloc[:, first_iloc] = deduped_column
-        else:
-            df.iloc[:, first_iloc] = df[label].values.tolist()
+        # Make a new column that combines the values for all instances of label
+        temp_column = []
 
-        # Temporarily rename first instance while others are dropped
+        for cell in df[label].values:
+            cell = [x for x in cell if not pd.isnull(x)]  # Remove None and nan
+
+            if deduplicate_values:
+                temp_column.append(set(cell))
+            else:
+                temp_column.append(cell)
+
+        df.insert(first_iloc, 'temp', temp_column)
+
+        # Drop the duplicate columns
         temp_labels = df.columns.tolist()
         temp_labels[first_iloc] = 'temp'
-        df.columns = temp_labels
-        df.drop(columns=label, inplace=True)
 
-        # Rename back to the original label
+        if label is None:
+            # drop() can't take None as a column name, so this is a workaround.
+            # As long df doesn't contain this exact label name, it will work
+            # as expected.
+            placeholder_label = '**be15492e-d01e-4ab9-9f2c-116525a26897**-label'
+            df.columns = [
+                placeholder_label if x is None else x for x in df.columns
+            ]
+            df.drop(columns=placeholder_label, inplace=True)
+        else:
+            df.drop(columns=label, inplace=True)
+
+        # Name the new column back to the original label
         temp_labels = df.columns.tolist()
         temp_labels[first_iloc] = label
         df.columns = temp_labels
